Original author
===============

PyMOSP is a free software written and maintained by:

* Cédric Bonhomme https://www.cedricbonhomme.org

# Contributors

* Copyright (C) 2019-2022 Cédric Bonhomme
* Copyright (C) 2019-2022 SECURITYMADEIN.LU

PyMOSP is licensed under
[GNU General Public License version 3])https://www.gnu.org/licenses/gpl-3.0.html)
